Learn R Programming

braQCA (version 1.4.11.27)

conf.table: Configuration Table

Description

Internal function; calculates via logistic regression the output of the Bootstrapped Robustness Recommendation

Usage

conf.table(data, ncut = ncut)

Value

The output of the Bootstrapped Recommendation #' @export

Arguments

data

name of the model object; the table of solutions for an application of QCA. Default set to data.

ncut

configurational n levels for inclusion. Default set to ncut=4