Internal function to calculate the Bootstrapped Recommendation.
sim.brQCA(
qca.data,
outcome = "OUT",
conditions = c(""),
sim = 10,
ncut = 2,
type = "crisp",
inclcut = "",
neg.out = FALSE,
verbose = TRUE
)Simulation information later passed on to conf.table.
the data frame of causal conditions.
the outcome variable (object name) in the QCA data frame of causal conditions; "OUT" is the outcome variable for an application of QCA. Default set to outcome="OUT".
a set of causal conditions. Default set to conditions=c("")
number of simulations to run. Default set to sim=10.
configurational n levels for inclusion. Default set to ncut=2.
type of QCA application, "crisp" or "fuzzy" sets. Default set to type = "crisp".
minimum sufficiency score for inclusion. Default set to inclcut="".
[from QCA package] ``Logical, use negation of outcome (ignored if data is a truth table object).'' Default set to neg.out=FALSE.
prints the system time used to run the simulation and the percent complete. Default set to verbose=TRUE.